package com.ruoyi.tcZz.service;

import java.util.List;
import com.ruoyi.tcZz.domain.TcIdcdw;
import com.ruoyi.tcZz.domain.TcWljg;

/**
 *  IDC单位Service接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface ITcIdcdwService 
{
    /**
     * 查询 IDC单位
     * 
     * @param id  IDC单位主键
     * @return  IDC单位
     */
    public TcIdcdw selectTcIdcdwById(Long id);

    /**
     * 查询 IDC单位列表
     * 
     * @param tcIdcdw  IDC单位
     * @return  IDC单位集合
     */
    public List<TcIdcdw> selectTcIdcdwList(TcIdcdw tcIdcdw);

    /**
     * 新增 IDC单位
     * 
     * @param tcIdcdw  IDC单位
     * @return 结果
     */
    public int insertTcIdcdw(TcIdcdw tcIdcdw);

    /**
     * 修改 IDC单位
     * 
     * @param tcIdcdw  IDC单位
     * @return 结果
     */
    public int updateTcIdcdw(TcIdcdw tcIdcdw);

    /**
     * 批量删除 IDC单位
     * 
     * @param ids 需要删除的 IDC单位主键集合
     * @return 结果
     */
    public int deleteTcIdcdwByIds(Long[] ids);

    /**
     * 删除 IDC单位信息
     * 
     * @param id  IDC单位主键
     * @return 结果
     */
    public int deleteTcIdcdwById(Long id);

    /**
     * 导入IDC单位信息
     *
     * @return 结果
     */
    public String importUser(List<TcIdcdw> tcIdcdwList);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
